package provide windows 1.18
#
proc install {argv} {
    global Type types Lib Bin CC LD Version Patchlevel Wish types cflags\
      libs share SCflag GCC SLDflag CFlags TIDir
#
    package require support
    package require -exact unixfile
#
    tk_dialog .wdz {Windows Installation} {Currently installing Zircon under\
    Windows is a hit or miss affair - I don't know enough about Windows to get\
    it all sorted out at the moment. The most important thing to note is that\
    DCC will not work as the C helper programs that implement it at the\]
    momeent are written for UNIX. However, this problem will go away when I
    implement my "all tcl" DCC code sometime in the future...} info \
      0 OK
    exit 1
#
    source [file join installer zircon.tcl]
    set Type {}
    set Lib {}
    set Bin {}
    set CC {}
    set LD ld
    set GCC 1
    set SCflag {}
    set SLDflag {}
    set CFlags {}
    set Wish {}
    set TIDir {}
    set go 0
#
    while {![string match {} $argv]} {
	set v [lindex $argv 1]
	switch -- [lindex $argv 0] {
	-b {set Bin $v }
	-c {set CC $v}
	-d {set LD $v}
	-f {set CFlags $v}
	-g {set go 1 ; set argv [lrange $argv 1 end] ; continue }
	-h {set TIDir $v}
	-l {set Lib $v }
	-s {set SCflag $v}
	-t {set Type $v }
	-w {set Wish $v}
	-z {set SLDflag $v}
	}
	set argv [lrange $argv 2 end]
    }
    catch {source install.in}
#
    set w [toplevel .inst]
    wm title $w {Zircon Installer}
    wm resizable $w 1 0 
    grid columnconfigure $w 1 -weight 1
    label $w.version -text "Zircon Version $Version\
      patchlevel $Patchlevel"
    grid $w.version -columnspan 2 -pady 5
#
# Zircon library directory
#
    button $w.lib -text {Library Directory}
    entry $w.libentry -textvariable Lib
    getLib
    gridIt $w lib [incr i]

#
# Zircon binary directory
#
    button $w.bin -text {Binary Directory}
    entry $w.binentry -textvariable Bin
    getBin
    gridIt $w bin [incr i]
#
# Wish
#
    button $w.wish -text {Tcl/Tk Interpreter}
    entry $w.wishentry -textvariable Wish
    getWish
    gridIt $w wish [incr i]
#
# Info
#
    grid [label $w.info] -columnspan 2 -sticky ew
    if {$go} { Go ; Quit }
#
# Buttons
#
    frame $w.btn
    button $w.btn.quit -text Quit -command Quit -width 12
    button $w.btn.install -text Install -command Go -width 12
    grid $w.btn.quit $w.btn.install
    grid $w.btn -columnspan 2 -sticky ew
}
#
proc makeLibrary {} {
    global Lib Manifest Index Patchlevel Version TIDir
    switch {} $TIDir {} default {
	if {![file exists [set TIDir [fixPath $TIDir]]]} {
	    fail "Directory \"$TIDir\" does not exist"
	    return 0
	}
	if {![file isdirectory $TIDir]} {
	    fail "\"$TIDir\" is not a directory"
	    return 0
	}
	if {![file exists [file join $TIDir tcl.h]]} {
	    fail "tcl.h does not exist in \"$TIDir\""
	    return 0
	}
    }
    if {[file exists [set Lib [fixPath $Lib]]]} {
	if {[file exists [set fn [file join $Lib installed]]]} {
	    set fd [open $fn r]
	    gets $fd line
	    close $fd
	    set ov [lindex $line 0]
	    set op [lindex $line 1]
	    set ext -$Version$Patchlevel
	    switch $ov $Version {
		switch $op $Patchlevel {
		   if {[askUser {Same Version} "You are installing version\
$Version $Patchlevel again.

Overwrite the existing version?"]} { set ext {} }
		}
	    }
	} {
	    set ext .old
	}
	switch {} $ext {} default {
	    if {[catch {filerename $Lib $Lib$ext} msg]} {
		if {![askUser Continue "Cannot rename $Lib to \
		  $Lib.old - \"$msg\"

Continue?"]} { return 0 }
	    }
	    if {[catch {filemkdir $Lib} msg]} {
		fail "Cannot make directory $Lib - \"$msg\""
		return 0
	    }
	}
    } \
    elseif {[catch {filemkdir $Lib} msg]} {
	fail "Cannot make directory $Lib - \"$msg\""
	return 0
    }
    foreach x [lsort [array names Manifest]] { 
	switch {} $Manifest($x) {} default {$Manifest($x) $x $Lib }
    }
    foreach x $Index {
	zinfo "Making package index for $x..."
	if {[catch {pkg_mkIndex [file join $Lib $x] *.tcl \
	  *[info sharedlibextension]} msg]} {
	    fail "Error whilst making package index for $x - \"$msg\""
	    return 0
	}
    }
    set fd [open [file join $Lib installed] a]
    puts $fd "$Version $Patchlevel {[clock format [clock seconds]]}"
    close $fd
    return 1}
#
proc makeBinary {} {
    zinfo "Making zircon..."
    global Bin Lib Version Patchlevel Wish
    if {![file exists [set Bin [fixPath $Bin]]]} {
	if {[catch {filemkdir $Bin} msg]} {
	    fail "Cannot create directory \"$Bin\" - $msg"
	    return 0
	}
    } \
    elseif {![file isdirectory $Bin]} {
	fail "\"$Bin\" is not a directory"
	return 0
    }
    set tf [file join $Bin zircon]
    if {[file exists $tf]} {
	if {[catch {filerename $tf $tf.old} msg]} {
	   fail "Cannot rename previous zircon executable - \"$msg\""
	   return 0
	}
    }
    if {[catch {open $tf w 0755} fd]} {
	fail "Cannot create zircon executable - \"$fd\""
	if {[file exists $tf.old]} {
	    file rename -force $tf.old $tf
	}
	return 0
    }
    puts $fd "#!$Wish"
    puts $fd "set zircon(lib) {$Lib}"
    puts $fd "#
proc zVersion {} {
    global zircon
    array set zircon {
	version		$Version
	patchlevel	$Patchlevel
    }
}
#"
    puts $fd [info body zircon]
    close $fd
    return 1}





